library('dplyr')
library('ggplot2')
library('reshape2')
library('RColorBrewer')

#heatmap THR vs CTRL
hallmark_ds <- c("Thr_CTRL")
clusters <- dir ("/DATA/31/molteni/vexas_bm/results/integration/GSEA_OSR_Wu/Thr_CTRL/")
clusters <- gsub("Thr_CTRL_markers_cluster_", "", clusters)

wdir="/DATA/31/molteni/vexas_bm/results/integration"

hallmark.full <- data.frame()
for (ds in hallmark_ds) {
  for (i in clusters) {
    s <- paste(ds,"markers_cluster", i,sep="_") #qui cambiare 1 con i e inserire ciclo for
    ff <- paste(wdir, "GSEA_OSR_Wu/Thr_CTRL", s, "tables", paste(s, "NA-gsea-h.all.v7.2.symbols.txt", sep = "-"), sep = "/")
    ds.t <- read.table(ff, header = T, sep = "\t")
    ds.t.filt <- ds.t[,c("ID", "setSize", "enrichmentScore", "NES", "pvalue", "p.adjust", "qvalues"), drop = FALSE]
    ds.t.filt$Dataset <- paste(ds,i,sep="_")
    if (nrow(hallmark.full) == 0) {
      hallmark.full <- ds.t.filt
    } else {
      hallmark.full <- rbind(hallmark.full, ds.t.filt)
    }
  }
}

hallmark.full_1 <- hallmark.full


### ONE HEATMAP ###

all_hallmark <- hallmark.full_1

all_hallmark$star <- cut(all_hallmark$p.adjust, breaks=c(-Inf, 0.001, 0.01, 0.05, Inf), label=c("***", "**", "*", ""))  # Create column of significance labels
all_hallmark$ID <- gsub(x = all_hallmark$ID, "HALLMARK_", "")
hallmark.order <- all_hallmark %>% group_by(ID) %>% summarise(Pos = sum(NES))
hallmark.order.terms <- hallmark.order[order(hallmark.order$Pos, decreasing = FALSE), "ID", drop = FALSE]
all_hallmark.nn <- melt(reshape2::dcast(all_hallmark, ID ~ Dataset, value.var="NES"), id.vars = c("ID"))
colnames(all_hallmark.nn) <- c("ID", "Dataset", "NES")
all_hallmark.pp <- melt(reshape2::dcast(all_hallmark, ID ~ Dataset, value.var="star"), id.vars = c("ID"))
colnames(all_hallmark.pp) <- c("ID", "Dataset", "STARS")
all_hallmark.tt <- merge(all_hallmark.nn,all_hallmark.pp)
all_hallmark.tt$ID <- factor(all_hallmark.tt$ID, levels = hallmark.order.terms$ID)

level_order <- c("Thr_CTRL_Late_erythroid_cells",
                 "Thr_CTRL_Mid_erythroid_cells",
                 "Thr_CTRL_Early_erythroid", 
                 "Thr_CTRL_Erythroid_progenitors",
                 "Thr_CTRL_MEP",
                 "Thr_CTRL_MEP_BASO_MAST_prog",
                 "Thr_CTRL_Plasmacytoid_dentritic_cells" ,
                 "Thr_CTRL_CD14+_CD16_low_monocytes",
                 "Thr_CTRL_CD14+_monocytes_2",
                 "Thr_CTRL_CD14+_monocytes_1",
                 "Thr_CTRL_Myeloid_dendritic_cells",
                 "Thr_CTRL_Immature_Neutrophil",
                 "Thr_CTRL_Prolif_GP",
                 "Thr_CTRL_GP",
                 "Thr_CTRL_HSC_MPP",
                 "Thr_CTRL_MLP",
                 "Thr_CTRL_CD4_T_cells",  
                 "Thr_CTRL_CD8_T_cells", 
                 "Thr_CTRL_B_cells",
                 "Thr_CTRL_Plasma_cells", 
                 "Thr_CTRL_VEXAS_GP", 
                 "Thr_CTRL_VEXAS_NK_cells")

#ALL 
all_hallmark.tt$Dataset <- factor(all_hallmark.tt$Dataset, levels =level_order )
p.hallmark <- ggplot(all_hallmark.tt, aes(x = Dataset, y = ID)) +
  theme_bw(base_size = 12) +
  theme(axis.text.x = element_text(angle = 45, hjust = 1)) +
  theme(axis.text.x=element_text(size=10))+
  theme(axis.text.y=element_text(size=8))+
  geom_tile(aes(fill = NES), colour = "white") +
  geom_text(aes(label = STARS), color="black", size=2) +
  ggtitle("GSEA OSR Thr Patients vs Control Pool") + 
  theme(plot.title = element_text(hjust = 0.5, vjust = 10), title = element_text(size=20, face = 'bold'))+
  theme(legend.title = element_text(size = 10))+
  scale_fill_gradientn(colours = colorRampPalette(rev(brewer.pal(11,"RdBu")))(100),
                       #limits = c(-3.5, 3.5),
                       limits = c(-4.5, 4.5),
                       na.value = "grey"
                       #guide = guide_colourbar(reverse = TRUE)
  ) +
  ylab("") + 
  xlab("") +
  coord_fixed(ratio = 0.4)

plot.dir="/DATA/31/molteni/vexas_bm/results/integration/heatmap_OSR_Wu/"

ggsave(filename = paste(plot.dir, paste("hallmark_Thr_CTRL", "heatmap.pdf", sep = "-"), sep = "/"), 
       plot = p.hallmark,
       width = 15, height = 15, dpi = 600)


#heatmap VAL vs CTRL
hallmark_ds <- c("Val_CTRL")
clusters <- dir ("/DATA/31/molteni/vexas_bm/results/integration/GSEA_OSR_Wu/Val_CTRL/")
clusters <- gsub("Val_CTRL_markers_cluster_", "", clusters)

wdir="/DATA/31/molteni/vexas_bm/results/integration"

hallmark.full <- data.frame()
for (ds in hallmark_ds) {
  for (i in clusters) {
    s <- paste(ds,"markers_cluster", i,sep="_") #qui cambiare 1 con i e inserire ciclo for
    ff <- paste(wdir, "GSEA_OSR_Wu/Val_CTRL", s, "tables", paste(s, "NA-gsea-h.all.v7.2.symbols.txt", sep = "-"), sep = "/")
    ds.t <- read.table(ff, header = T, sep = "\t")
    ds.t.filt <- ds.t[,c("ID", "setSize", "enrichmentScore", "NES", "pvalue", "p.adjust", "qvalues"), drop = FALSE]
    ds.t.filt$Dataset <- paste(ds,i,sep="_")
    if (nrow(hallmark.full) == 0) {
      hallmark.full <- ds.t.filt
    } else {
      hallmark.full <- rbind(hallmark.full, ds.t.filt)
    }
  }
}

hallmark.full_2 <- hallmark.full


### ONE HEATMAP ###

all_hallmark <- hallmark.full_2

all_hallmark$star <- cut(all_hallmark$p.adjust, breaks=c(-Inf, 0.001, 0.01, 0.05, Inf), label=c("***", "**", "*", ""))  # Create column of significance labels
all_hallmark$ID <- gsub(x = all_hallmark$ID, "HALLMARK_", "")
hallmark.order <- all_hallmark %>% group_by(ID) %>% summarise(Pos = sum(NES))
hallmark.order.terms <- hallmark.order[order(hallmark.order$Pos, decreasing = FALSE), "ID", drop = FALSE]
all_hallmark.nn <- melt(reshape2::dcast(all_hallmark, ID ~ Dataset, value.var="NES"), id.vars = c("ID"))
colnames(all_hallmark.nn) <- c("ID", "Dataset", "NES")
all_hallmark.pp <- melt(reshape2::dcast(all_hallmark, ID ~ Dataset, value.var="star"), id.vars = c("ID"))
colnames(all_hallmark.pp) <- c("ID", "Dataset", "STARS")
all_hallmark.tt <- merge(all_hallmark.nn,all_hallmark.pp)
all_hallmark.tt$ID <- factor(all_hallmark.tt$ID, levels = hallmark.order.terms$ID)

#

level_order <- c("Val_CTRL_Late_erythroid_cells",
                 "Val_CTRL_Mid_erythroid_cells",
                 "Val_CTRL_Early_erythroid", 
                 "Val_CTRL_Erythroid_progenitors",
                 "Val_CTRL_MEP",
                 "Val_CTRL_MEP_BASO_MAST_prog",
                 "Val_CTRL_Plasmacytoid_dentritic_cells" ,
                 "Val_CTRL_CD14+_CD16_low_monocytes",
                 "Val_CTRL_CD14+_monocytes_2",
                 "Val_CTRL_CD14+_monocytes_1",
                 "Val_CTRL_Myeloid_dendritic_cells",
                 "Val_CTRL_Immature_Neutrophil",
                 "Val_CTRL_Prolif_GP",
                 "Val_CTRL_GP",
                 "Val_CTRL_HSC_MPP",
                 "Val_CTRL_MLP",
                 "Val_CTRL_CD4_T_cells",  
                 "Val_CTRL_CD8_T_cells", 
                 "Val_CTRL_B_cells",
                 "Val_CTRL_Plasma_cells",
                 "Val_CTRL_Endothelial_cells",
                 "Val_CTRL_VEXAS_GP", 
                 "Val_CTRL_VEXAS_NK_cells")

#ALL 
all_hallmark.tt$Dataset <- factor(all_hallmark.tt$Dataset, levels =level_order )
p.hallmark <- ggplot(all_hallmark.tt, aes(x = Dataset, y = ID)) +
  theme_bw(base_size = 12) +
  theme(axis.text.x = element_text(angle = 45, hjust = 1)) +
  theme(axis.text.x=element_text(size=10))+
  theme(axis.text.y=element_text(size=8))+
  geom_tile(aes(fill = NES), colour = "white") +
  geom_text(aes(label = STARS), color="black", size=2) +
  ggtitle("GSEA Val OSR Patients vs Control Pool") + 
  theme(plot.title = element_text(hjust = 0.5, vjust = 10), title = element_text(size=20, face = 'bold'))+
  theme(legend.title = element_text(size = 10))+
  scale_fill_gradientn(colours = colorRampPalette(rev(brewer.pal(11,"RdBu")))(100),
                       #limits = c(-3.5, 3.5),
                       limits = c(-4.5, 4.5),
                       na.value = "grey"
                       #guide = guide_colourbar(reverse = TRUE)
  ) +
  ylab("") + 
  xlab("") +
  coord_fixed(ratio = 0.4)

plot.dir="/DATA/31/molteni/vexas_bm/results/integration/heatmap_OSR_Wu/"

ggsave(filename = paste(plot.dir, paste("hallmark_Val_CTRL", "heatmap.pdf", sep = "-"), sep = "/"), 
       plot = p.hallmark,
       width = 15, height = 15, dpi = 600)

#heatmap LEU vs CTRL

hallmark_ds <- c("Leu_CTRL")
clusters <- dir ("/DATA/31/molteni/vexas_bm/results/integration/GSEA_OSR_Wu/Leu_CTRL/")
clusters <- gsub("Leu_CTRL_markers_cluster_", "", clusters)

wdir="/DATA/31/molteni/vexas_bm/results/integration"

hallmark.full <- data.frame()
for (ds in hallmark_ds) {
  for (i in clusters) {
    s <- paste(ds,"markers_cluster", i,sep="_") #qui cambiare 1 con i e inserire ciclo for
    ff <- paste(wdir, "GSEA_OSR_Wu/Leu_CTRL", s, "tables", paste(s, "NA-gsea-h.all.v7.2.symbols.txt", sep = "-"), sep = "/")
    ds.t <- read.table(ff, header = T, sep = "\t")
    ds.t.filt <- ds.t[,c("ID", "setSize", "enrichmentScore", "NES", "pvalue", "p.adjust", "qvalues"), drop = FALSE]
    ds.t.filt$Dataset <- paste(ds,i,sep="_")
    if (nrow(hallmark.full) == 0) {
      hallmark.full <- ds.t.filt
    } else {
      hallmark.full <- rbind(hallmark.full, ds.t.filt)
    }
  }
}

hallmark.full_3 <- hallmark.full


### ONE HEATMAP ###

all_hallmark <- hallmark.full_3

all_hallmark$star <- cut(all_hallmark$p.adjust, breaks=c(-Inf, 0.001, 0.01, 0.05, Inf), label=c("***", "**", "*", ""))  # Create column of significance labels
all_hallmark$ID <- gsub(x = all_hallmark$ID, "HALLMARK_", "")
hallmark.order <- all_hallmark %>% group_by(ID) %>% summarise(Pos = sum(NES))
hallmark.order.terms <- hallmark.order[order(hallmark.order$Pos, decreasing = FALSE), "ID", drop = FALSE]
all_hallmark.nn <- melt(reshape2::dcast(all_hallmark, ID ~ Dataset, value.var="NES"), id.vars = c("ID"))
colnames(all_hallmark.nn) <- c("ID", "Dataset", "NES")
all_hallmark.pp <- melt(reshape2::dcast(all_hallmark, ID ~ Dataset, value.var="star"), id.vars = c("ID"))
colnames(all_hallmark.pp) <- c("ID", "Dataset", "STARS")
all_hallmark.tt <- merge(all_hallmark.nn,all_hallmark.pp)
all_hallmark.tt$ID <- factor(all_hallmark.tt$ID, levels = hallmark.order.terms$ID)

#

level_order <- c("Leu_CTRL_Late_erythroid_cells",
                 "Leu_CTRL_Mid_erythroid_cells",
                 "Leu_CTRL_Early_erythroid", 
                 "Leu_CTRL_Erythroid_progenitors",
                 "Leu_CTRL_MEP",
                 "Leu_CTRL_MEP_BASO_MAST_prog",
                 "Leu_CTRL_Plasmacytoid_dentritic_cells" ,
                 "Leu_CTRL_CD14+_CD16_low_monocytes",
                 "Leu_CTRL_CD14+_monocytes_2",
                 "Leu_CTRL_CD14+_monocytes_1",
                 "Leu_CTRL_Myeloid_dendritic_cells",
                 "Leu_CTRL_Immature_Neutrophil",
                 "Leu_CTRL_Prolif_GP",
                 "Leu_CTRL_GP",
                 "Leu_CTRL_HSC_MPP",
                 "Leu_CTRL_MLP",
                 "Leu_CTRL_CD4_T_cells",  
                 "Leu_CTRL_CD8_T_cells", 
                 "Leu_CTRL_B_cells",
                 "Leu_CTRL_Plasma_cells",
                 "Leu_CTRL_Endothelial_cells",
                 "Leu_CTRL_VEXAS_GP", 
                 "Leu_CTRL_VEXAS_NK_cells")


#ALL 
all_hallmark.tt$Dataset <- factor(all_hallmark.tt$Dataset, levels =level_order )
p.hallmark <- ggplot(all_hallmark.tt, aes(x = Dataset, y = ID)) +
  theme_bw(base_size = 12) +
  theme(axis.text.x = element_text(angle = 45, hjust = 1)) +
  theme(axis.text.x=element_text(size=10))+
  theme(axis.text.y=element_text(size=8))+
  geom_tile(aes(fill = NES), colour = "white") +
  geom_text(aes(label = STARS), color="black", size=2) +
  ggtitle("GSEA Leu OSR Patients vs Control Pool") + 
  theme(plot.title = element_text(hjust = 0.5, vjust = 10), title = element_text(size=20, face = 'bold'))+
  theme(legend.title = element_text(size = 10))+
  scale_fill_gradientn(colours = colorRampPalette(rev(brewer.pal(11,"RdBu")))(100),
                       #limits = c(-3.5, 3.5),
                       limits = c(-4.5, 4.5),
                       na.value = "grey"
                       #guide = guide_colourbar(reverse = TRUE)
  ) +
  ylab("") + 
  xlab("") +
  coord_fixed(ratio = 0.4)

plot.dir="/DATA/31/molteni/vexas_bm/results/integration/heatmap_OSR_Wu/"

ggsave(filename = paste(plot.dir, paste("hallmark_Leu_CTRL", "heatmap.pdf", sep = "-"), sep = "/"), 
       plot = p.hallmark,
       width = 15, height = 15, dpi = 600)


###ONE HEATMAP 

all_hallmark <- rbind (hallmark.full_1, hallmark.full_2, hallmark.full_3)


all_hallmark$star <- cut(all_hallmark$p.adjust, breaks=c(-Inf, 0.001, 0.01, 0.05, Inf), label=c("***", "**", "*", ""))  # Create column of significance labels
all_hallmark$ID <- gsub(x = all_hallmark$ID, "HALLMARK_", "")
hallmark.order <- all_hallmark %>% group_by(ID) %>% summarise(Pos = sum(NES))
hallmark.order.terms <- hallmark.order[order(hallmark.order$Pos, decreasing = FALSE), "ID", drop = FALSE]
hallmark.order.terms <- hallmark.order[order(hallmark.order$ID, decreasing = TRUE), "ID", drop = FALSE]

all_hallmark.nn <- melt(reshape2::dcast(all_hallmark, ID ~ Dataset, value.var="NES"), id.vars = c("ID"))
colnames(all_hallmark.nn) <- c("ID", "Dataset", "NES")
all_hallmark.pp <- melt(reshape2::dcast(all_hallmark, ID ~ Dataset, value.var="star"), id.vars = c("ID"))
colnames(all_hallmark.pp) <- c("ID", "Dataset", "STARS")
all_hallmark.tt <- merge(all_hallmark.nn,all_hallmark.pp)
all_hallmark.tt$ID <- factor(all_hallmark.tt$ID, levels = hallmark.order.terms$ID)

#ONE VS ALL COMPARISON ##

level_order <- c("Thr_CTRL_Late_erythroid_cells","Val_CTRL_Late_erythroid_cells","Leu_CTRL_Late_erythroid_cells",
                 "Thr_CTRL_Mid_erythroid_cells","Val_CTRL_Mid_erythroid_cells","Leu_CTRL_Mid_erythroid_cells",
                 "Thr_CTRL_Early_erythroid",  "Val_CTRL_Early_erythroid", "Leu_CTRL_Early_erythroid", 
                 "Thr_CTRL_Erythroid_progenitors", "Val_CTRL_Erythroid_progenitors","Leu_CTRL_Erythroid_progenitors",
                 "Thr_CTRL_MEP","Val_CTRL_MEP","Leu_CTRL_MEP",
                 "Thr_CTRL_MEP_BASO_MAST_prog","Val_CTRL_MEP_BASO_MAST_prog","Leu_CTRL_MEP_BASO_MAST_prog",
                 "Thr_CTRL_Plasmacytoid_dentritic_cells", "Val_CTRL_Plasmacytoid_dentritic_cells","Leu_CTRL_Plasmacytoid_dentritic_cells",
                 "Thr_CTRL_CD14+_CD16_low_monocytes","Val_CTRL_CD14+_CD16_low_monocytes","Leu_CTRL_CD14+_CD16_low_monocytes",
                 "Thr_CTRL_CD14+_monocytes_2","Val_CTRL_CD14+_monocytes_2","Leu_CTRL_CD14+_monocytes_2",
                 "Thr_CTRL_CD14+_monocytes_1", "Val_CTRL_CD14+_monocytes_1","Leu_CTRL_CD14+_monocytes_1",
                 "Thr_CTRL_Myeloid_dendritic_cells", "Val_CTRL_Myeloid_dendritic_cells","Leu_CTRL_Myeloid_dendritic_cells",
                 "Thr_CTRL_Immature_Neutrophil","Val_CTRL_Immature_Neutrophil","Leu_CTRL_Immature_Neutrophil",
                 "Thr_CTRL_Prolif_GP","Val_CTRL_Prolif_GP","Leu_CTRL_Prolif_GP",
                 "Thr_CTRL_GP","Val_CTRL_GP","Leu_CTRL_GP",
                 "Thr_CTRL_HSC_MPP", "Val_CTRL_HSC_MPP","Leu_CTRL_HSC_MPP",
                 "Thr_CTRL_MLP", "Val_CTRL_MLP","Leu_CTRL_MLP",
                 "Thr_CTRL_CD4_T_cells", "Val_CTRL_CD4_T_cells","Leu_CTRL_CD4_T_cells",
                 "Thr_CTRL_CD8_T_cells", "Val_CTRL_CD8_T_cells", "Leu_CTRL_CD8_T_cells", 
                 "Thr_CTRL_B_cells","Val_CTRL_B_cells","Leu_CTRL_B_cells",
                 "Thr_CTRL_Plasma_cells","Val_CTRL_Plasma_cells","Leu_CTRL_Plasma_cells", 
                 "Val_CTRL_Endothelial_cells", "Leu_CTRL_Endothelial_cells",
                 "Thr_CTRL_VEXAS_GP", "Val_CTRL_VEXAS_GP","Leu_CTRL_VEXAS_GP",
                 "Thr_CTRL_VEXAS_NK_cells", "Val_CTRL_VEXAS_NK_cells", "Leu_CTRL_VEXAS_NK_cells")


#ALL 
all_hallmark.tt$Dataset <- factor(all_hallmark.tt$Dataset, levels =level_order )
p.hallmark <- ggplot(all_hallmark.tt, aes(x = Dataset, y = ID)) +
  theme_bw(base_size = 12) +
  theme(axis.text.x = element_text(angle = 45, hjust = 1)) +
  theme(axis.text.x=element_text(size=10))+
  theme(axis.text.y=element_text(size=8))+
  geom_tile(aes(fill = NES), colour = "white") +
  geom_text(aes(label = STARS), color="black", size=2) +
  ggtitle("GSEA - All Mutations OSR Patients vs Control") + 
  theme(plot.title = element_text(hjust = 0.5, vjust = 10), title = element_text(size=20, face = 'bold'))+
  theme(legend.title = element_text(size = 10))+
  scale_fill_gradientn(colours = colorRampPalette(rev(brewer.pal(11,"RdBu")))(100),
                       #limits = c(-3.5, 3.5),
                       limits = c(-4.5, 4.5),
                       na.value = "grey"
                       #guide = guide_colourbar(reverse = TRUE)
  ) +
  ylab("") + 
  xlab("") +
  coord_fixed(ratio = 0.4)

plot.dir="/DATA/31/molteni/vexas_bm/results/integration/heatmap_OSR_Wu/"

ggsave(filename = paste(plot.dir, paste("hallmark_ALLMut", "heatmap.pdf", sep = "-"), sep = "/"), 
       plot = p.hallmark,
       width = 20, height = 10, dpi = 600)


## PAZIENTI vs CONTROLLI ##

#heatmap PZ vs CTRL
hallmark_ds <- c("Pz_CTRL")
clusters <- dir ("/DATA/31/molteni/vexas_bm/results/integration/GSEA_OSR_Wu/Pz_CTRL/")
clusters <- gsub("Pz_CTRL_markers_cluster_", "", clusters)

wdir="/DATA/31/molteni/vexas_bm/results/integration"

hallmark.full <- data.frame()
for (ds in hallmark_ds) {
  for (i in clusters) {
    s <- paste(ds,"markers_cluster", i,sep="_") #qui cambiare 1 con i e inserire ciclo for
    ff <- paste(wdir, "GSEA_OSR_Wu/Pz_CTRL", s, "tables", paste(s, "NA-gsea-h.all.v7.2.symbols.txt", sep = "-"), sep = "/")
    ds.t <- read.table(ff, header = T, sep = "\t")
    ds.t.filt <- ds.t[,c("ID", "setSize", "enrichmentScore", "NES", "pvalue", "p.adjust", "qvalues"), drop = FALSE]
    ds.t.filt$Dataset <- paste(ds,i,sep="_")
    if (nrow(hallmark.full) == 0) {
      hallmark.full <- ds.t.filt
    } else {
      hallmark.full <- rbind(hallmark.full, ds.t.filt)
    }
  }
}

hallmark.full_4 <- hallmark.full


### ONE HEATMAP ###

all_hallmark <- hallmark.full_4

all_hallmark$star <- cut(all_hallmark$p.adjust, breaks=c(-Inf, 0.001, 0.01, 0.05, Inf), label=c("***", "**", "*", ""))  # Create column of significance labels
all_hallmark$ID <- gsub(x = all_hallmark$ID, "HALLMARK_", "")
hallmark.order <- all_hallmark %>% group_by(ID) %>% summarise(Pos = sum(NES))
hallmark.order.terms <- hallmark.order[order(hallmark.order$Pos, decreasing = FALSE), "ID", drop = FALSE]
all_hallmark.nn <- melt(reshape2::dcast(all_hallmark, ID ~ Dataset, value.var="NES"), id.vars = c("ID"))
colnames(all_hallmark.nn) <- c("ID", "Dataset", "NES")
all_hallmark.pp <- melt(reshape2::dcast(all_hallmark, ID ~ Dataset, value.var="star"), id.vars = c("ID"))
colnames(all_hallmark.pp) <- c("ID", "Dataset", "STARS")
all_hallmark.tt <- merge(all_hallmark.nn,all_hallmark.pp)
all_hallmark.tt$ID <- factor(all_hallmark.tt$ID, levels = hallmark.order.terms$ID)

level_order <- c("Pz_CTRL_Late_erythroid_cells",
                 "Pz_CTRL_Mid_erythroid_cells",
                 "Pz_CTRL_Early_erythroid", 
                 "Pz_CTRL_Erythroid_progenitors",
                 "Pz_CTRL_MEP",
                 "Pz_CTRL_MEP_BASO_MAST_prog",
                 "Pz_CTRL_Plasmacytoid_dentritic_cells" ,
                 "Pz_CTRL_CD14+_CD16_low_monocytes",
                 "Pz_CTRL_CD14+_monocytes_2",
                 "Pz_CTRL_CD14+_monocytes_1",
                 "Pz_CTRL_Myeloid_dendritic_cells",
                 "Pz_CTRL_Immature_Neutrophil",
                 "Pz_CTRL_Prolif_GP",
                 "Pz_CTRL_GP",
                 "Pz_CTRL_HSC_MPP",
                 "Pz_CTRL_MLP",
                 "Pz_CTRL_CD4_T_cells",  
                 "Pz_CTRL_CD8_T_cells", 
                 "Pz_CTRL_B_cells",
                 "Pz_CTRL_Plasma_cells",
                 "Pz_CTRL_Endothelial_cells",
                 "Pz_CTRL_VEXAS_GP", 
                 "Pz_CTRL_VEXAS_NK_cells")
#ALL 
all_hallmark.tt$Dataset <- factor(all_hallmark.tt$Dataset, levels =level_order )
p.hallmark <- ggplot(all_hallmark.tt, aes(x = Dataset, y = ID)) +
  theme_bw(base_size = 12) +
  theme(axis.text.x = element_text(angle = 45, hjust = 1)) +
  theme(axis.text.x=element_text(size=10))+
  theme(axis.text.y=element_text(size=8))+
  geom_tile(aes(fill = NES), colour = "white") +
  geom_text(aes(label = STARS), color="black", size=2) +
  ggtitle("GSEA OSR Patients vs Control Pool") + 
  theme(plot.title = element_text(hjust = 0.5, vjust = 10), title = element_text(size=20, face = 'bold'))+
  theme(legend.title = element_text(size = 10))+
  scale_fill_gradientn(colours = colorRampPalette(rev(brewer.pal(11,"RdBu")))(100),
                       #limits = c(-3.5, 3.5),
                       limits = c(-4.5, 4.5),
                       na.value = "grey"
                       #guide = guide_colourbar(reverse = TRUE)
  ) +
  ylab("") + 
  xlab("") +
  coord_fixed(ratio = 0.4)

plot.dir="/DATA/31/molteni/vexas_bm/results/integration/heatmap_OSR_Wu/"

ggsave(filename = paste(plot.dir, paste("hallmark_Pz_CTRL", "heatmap.pdf", sep = "-"), sep = "/"), 
       plot = p.hallmark,
       width = 15, height = 15, dpi = 600)

